***Pulled-Over Rates, Causal Attributions, and Trust in Police
*Referred to as Study 1 in the PRQ Paper
*Data collected by Clear Voice Research, June 18-28, 2016

*ssc install outreg2

**Experimental Condition
*Kevin (1)|Kevin (2) is control. Trust question first, then presented disparity info and asked about attribution
*Kevin (2)|Kevin (1) is treatment. Racial disparity info present and asked for attribution, and then trust in police is presented.
tab KevinGroup

***Demographics/Controls

*Ideology, 1=Very liberal, 7=Very conservative
*ren Q11_3_1 ideo
tab ideo

*ren Q11_1 gender
*Gender, 1=Male, 2=Female
tab gender
gen sex=.
replace sex=0 if gender==1
replace sex=1 if gender==2
tab sex
label define sex 0 "Male" 1 "Female"
label values sex sex
tab sex

*Age
gen AGE=real( Q26_3 )
drop if AGE<=1926
drop if AGE>=2000
gen age=(2016-AGE)
tabstat age
recode age 1/25=1 26/35=2 36/45=3 46/55=4 56/65=5 66/94=6
label define page 1"18-25" 2"26-35" 3"36-45" 4"46-55" 5"56-65" 6"65 and up"
label values age page
tab age

*ren Q26_2 educ
tab educ

*ren Q26_5 income
tab income

*Recode race, 3 categories, 1=black, 2= white, 3=other
*ren Q26_4 race
tab race
gen race3=.
replace race3=1 if race==5
replace race3=2 if race==1
replace race3=3 if race==2
replace race3=3 if race==3
replace race3=3 if race==4
replace race3=3 if race==6
tab race3
label define race3 1 "White" 2 "Black" 3 "Other
label values race3 race3
tab race3

**************************************************************

*****Trust in Police
**How much trust do you have in police officers to treat people fairly?
*1=Almost no trust at all, 2=a little, 3=A moderate amount, 4=A lot, 5= Almost complete trust
tab Q20_1
gen trust=.
replace trust=1 if Q20_1==1
replace trust=2 if Q20_1==2
replace trust=3 if Q20_1==3
replace trust=4 if Q20_1==4
replace trust=5 if Q20_1==5
tab trust

**Attributions
*Research shows black drivers are more likely to be pulled over for minor traffic violations than white drivers. What do you think is the primary reason this occurs?
*1=blacks commit more traffic violations, 2=police are racially profiling, 3=police are more likely to be in areas where blacks drive, 4=other, 5=don't know
tab Q21_1
gen att=.
replace att=1 if Q21_1==1
replace att=2 if Q21_1==2
replace att=3 if Q21_1==3
replace att=4 if Q21_1==4
replace att=5 if Q21_1==5
tab att
label define att 1 "Blacks commit more violations" 2 "Police racially profile" 3 "Police more likely in areas where blacks drive" 4 "Other" 5 "Don't know"
label values att att
tab att


**Regression Model: Trust by attribution controlling for other variables. Analysis restricted to Control group.
regress trust i.att i.race3 age ideo educ income sex if KevinGroup=="Kevin (1)|Kevin (2)", robust
*outreg2 using myreg.doc, replace ctitle(Model 1) label sideway
margins, dydx(i.att)
marginsplot, recast(scatter) scheme(s1mono) horizontal title("Effect of Attribution on Trust in Police (Study 1)", size (medium) margin(medium)) xline(0,lpattern(dash)) ytitle("Attribution for Racial Disparities", margin(small)) yscale(rev range(1.5 5.5)) ylabel(2 "Police racially profile" 3 "Police more likely where blacks live" 4 "Other" 5 "Don't Know", labsize(small)) xtitle("Predicted Change in Trust", margin(small) )
*graph export Study1TrustFinal.pdf, replace


*Treatment effects by attribution
ttest trust if(att==1), by(KevinGroup)
ttest trust if(att==2), by(KevinGroup)
ttest trust if(att==3), by(KevinGroup)
ttest trust if(att==4), by(KevinGroup)
ttest trust if(att==5), by(KevinGroup)
ttest trust, by(KevinGroup)

ttest trust if(KevinGroup=="Kevin (1)|Kevin (2)" & att==1 |KevinGroup=="Kevin (1)|Kevin (2)" & att==3), by(att)





**************************
*Supplementary Materials**
**************************


**Distribution of attrbutions
tab att KevinGroup, column
tabulate att KevinGroup, column chi2

**Distribution of trust in police
tab trust KevinGroup, column
tabstat trust, stats(mean sd sem n)
ttest trust, by(KevinGroup)

**Trust by attribution type. Group 1 is the appropriate condition for these analyses.
tabstat trust if KevinGroup=="Kevin (1)|Kevin (2)", by(att) stats(mean sem p50 n)

**Ordered logit model
ologit trust i.att i.race3 age ideo educ income sex if KevinGroup=="Kevin (1)|Kevin (2)", robust
margins i.att if(att==1 | att==2 ), atmeans vsquish
marginsplot, scheme(s1mono) horizontal title("Trust in Police by Attribution (Study 1)", size (medium) margin(medium)) ylab() ytitle("Attribution for Racial Disparities") yscale(range(.5 2.5)) xtitle("Predicted Trust in Police")
*graph export Study1TrustOlogit.pdf, replace
*outreg2 using myreg.doc, replace ctitle(Model 1) label sideway


**If party is controlled for.
gen partyid=.
replace partyid=1 if Q11_6==1
replace partyid=2 if Q11_6==2
replace partyid=3 if Q11_7==2
replace partyid=4 if Q11_7==3
replace partyid=5 if Q11_7==1
replace partyid=6 if Q11_5==2
replace partyid=7 if Q11_5==1
tab partyid
*Create Party ID in three categories, leaners as partisans
gen PartyID3=.
replace PartyID3=1 if partyid==1
replace PartyID3=1 if partyid==2
replace PartyID3=1 if partyid==3
replace PartyID3=2 if partyid==4
replace PartyID3=3 if partyid==5
replace PartyID3=3 if partyid==6
replace PartyID3=3 if partyid==7
tab PartyID3
label define PartyID3 1 "Democrat" 2 "Independent" 3 "Republican"
label values PartyID3 PartyID3
tab PartyID3

gen repub=.
replace repub=1 if PartyID3==3
replace repub=0 if PartyID3==1
replace repub=0 if PartyID3==2
tab repub

gen indep=.
replace indep=1 if PartyID3==2
replace indep=0 if PartyID3==1
replace indep=0 if PartyID3==3
tab indep

regress trust i.att i.race3 age ideo educ income sex repub indep  if KevinGroup=="Kevin (1)|Kevin (2)", robust
*outreg2 using myreg.doc, replace ctitle(Model 1) label sideway

**Full Sample Regression with dummy for experimental condition.
gen kgroup=.
replace kgroup=0 if KevinGroup=="Kevin (1)|Kevin (2)"
replace kgroup=1 if KevinGroup=="Kevin (2)|Kevin (1)"
tab kgroup
 
regress trust i.att i.race3 age ideo educ income sex kgroup, robust
*outreg2 using myreg.doc, replace ctitle(Model 1) label sideway


**Treatment Effect Figure for Appendix
regress trust i.att i.kgroup i.att##i.kgroup
margins att, dydx(i.kgroup)
marginsplot, recast(scatter) scheme(s1mono) horizontal title("Change in Trust (Treatment Effect) by Attribution (Study 1)", size (medium) margin(medium)) xline(0,lpattern(dash)) ytitle("Attribution for Racial Disparitiy", margin(small)) yscale(rev range(0.5 5.5)) ylabel( 1 "Blacks commit more violations" 2 "Police racially profile" 3 "Police more likely where blacks live" 4 "Other" 5 "Don't Know", labsize(small)) xtitle("Change in Trust (Treatment Effect)", margin(small) )
*graph export Study1TreatmentEffectPlot.pdf, replace


***Predicting the attribution types
gen interest=.
replace interest=1 if polint==4
replace interest=2 if polint==3
replace interest=3 if polint==2
replace interest=4 if polint==1
tab interest

mlogit att i.race3 age ideo educ income sex repub indep interest, baseoutcome(2)
*outreg2 using myreg.doc, replace label sideway


*********************************************
*Additional analyses referenced in the paper*
*********************************************

*There doesn't seem to an interaction between race and the attributions for trust in police
gen race2=.
replace race2=0 if race3==1
replace race2=1 if race3==2
tab race2

regress trust i.att i.race3 age ideo educ income sex i.att#i.race2  if KevinGroup=="Kevin (1)|Kevin (2)", robust




