****Pulled Over Rates, Causal Attributions, and Trust in Police
**Follow-up study
**Carried out with SSI, April 20-27, 2017

**Experimental Condition
tab Condition

gen group=.
replace group=0 if Condition=="Control"
replace group=1 if Condition=="Treatment"
tab group

***Demographics
tab Ideology

tab Age

tab Educ
gen edu=.
replace edu=1 if Educ==1
replace edu=2 if Educ==2
replace edu=3 if Educ==3
replace edu=3 if Educ==4
replace edu=4 if Educ==5
replace edu=5 if Educ==6
replace edu=5 if Educ==7
replace edu=5 if Educ==8
tab edu

tab Income

tab Sex
gen sex=.
replace sex=0 if Sex==1
replace sex=1 if Sex==2
tab sex
label define sex 0 "Male" 1 "Female"
label values sex sex
tab sex

gen race3=.
replace race3=0 if Race_1==1
replace race3=1 if Race_2==1 
replace race3=2 if Race_3==1
replace race3=2 if Race_4==1
replace race3=2 if Race_5==1
replace race3=2 if Race_6==1
tab race3
label define race3 0 "White" 1 "Black" 2 "Other"
label values race3 race3
tab race3

***Control Variables
*Worry about being a victim of a crime
tab Worry1
gen worry=Worry1-14
tab worry

*How safe do you feel in your neighborhood
tab Safe

*Neighborhood quality, Index average of 4 items
tab Hood_1
gen hood1=Hood_1-12
tab hood1
tab Hood_2
gen hood2=Hood_2-12
tab hood2
tab Hood_3
gen hood3=Hood_3-12
tab hood3
tab Hood_4
gen hood4=Hood_4-12
tab hood4
gen hood=(hood1 + hood2 + hood3 + hood4)/4
tab hood


*Experience with police
tab Stop1
gen stop1=.
replace stop1=0 if Stop1==2
replace stop1=1 if Stop1==1
tab stop1

tab Stop2
gen stop2=.
replace stop2=0 if Stop2==2
replace stop2=1 if Stop2==1
tab stop2

tab Insult1
gen insult1=.
replace insult1=0 if Insult1==2
replace insult1=1 if Insult1==1
tab insult1

tab Insult2
gen insult2=.
replace insult2=0 if Insult2==2
replace insult2=1 if Insult2==1
tab insult2

tab Force1
gen force1=.
replace force1=0 if Force1==2
replace force1=1 if Force1==1
tab force1

tab Force2
gen force2=.
replace force2=0 if Force2==2
replace force2=1 if Force2==1
tab force2

gen experience=(stop1 + stop2 + insult1 + insult2 + force1 + force2)/6
tab experience

**************************************************************
*Trust in police
tab Q1
gen trustq=Q1-14
tab trustq


*Attribution. In this study, people who selected "Don't know" were given a follow-up. Below, we take people's responses to the follow-up and put them in their respective attribution categories.
*Black drivers are committing more traffic violations than white drivers (1)
*Police are racially profiling drivers (2)
*Police are more likely to be in areas where blacks drive (3)
*Don't know (4)
tab AttributionQ

tab AttFollow
gen attlean=AttributionQ
replace attlean=1 if AttFollow==1
replace attlean=2 if AttFollow==2
replace attlean=3 if AttFollow==3
replace attlean=4 if AttFollow==4
tab attlean
label define attlean 1 "Blacks commit more violations" 2 "Police racially profile" 3 "Police more likely in areas where blacks drive" 4 "Don't know"
label values attlean attlean
tab attlean

**Full Model: Trust by attribution controlling for other variables. Analysis restricted to Control group.
regress trustq i.attlean i.race3 Age Ideology edu Income sex worry Safe hood experience if Condition=="Control", robust 
*outreg2 using myreg.doc, replace ctitle(Model 1) label sideway
margins, dydx(i.attlean)
marginsplot, recast(scatter) scheme(s1mono) horizontal title("Effect of Attribution on Trust in Police (Study 2)", size (medium) margin(medium)) xline(0,lpattern(dash)) ytitle("Attribution for Racial Disparities", margin(small)) yscale(rev range(1.5 4.5)) ylabel(2 "Police racially profile" 3 "Police more likely where blacks live" 4 "Don't Know", labsize(small)) xtitle("Predicted Change in Trust", margin(small) )
*graph export Study2TrustFinal.pdf, replace


*Treatment effects by attribution
ttest trustq if(attlean==1), by(Condition)
ttest trustq if(attlean==2), by(Condition)
ttest trustq if(attlean==3), by(Condition)
ttest trustq if(attlean==4), by(Condition)
ttest trustq, by(Condition)


ttest trustq if(Condition=="Control" & attlean==1 | Condition=="Control" & attlean==3), by(attlean)


**************************************************************

*************************
*Supplemental Materials**
*************************


**Distribution of Attributions
*Black drivers are committing more traffic violations than white drivers (1)
*Police are racially profiling drivers (2)
*Police are more likely to be in areas where blacks drive (3)
*Don't know (4)
tab attlean
tab attlean Condition, column
tabulate attlean Condition, column chi2

**Distribution of trust in police
*Q1 How much trust do you have in police officers to treat people fairly?
*1=Almost no trust at all, 4=a moderate amount, 7 almost complete trust 
*tab Q1
*gen trustq=Q1-14
*tab trustq
tab trustq Condition, column
tabstat trustq, stats(mean sd sem n)
tabstat trustq, by(Condition) stats(mean sd sem n)
ttest trustq, by(Condition)

**Trust by attribution type. Group 1 is the appropriate condition for these analyses.
tabstat trustq if Condition=="Control", by(attlean) stats(mean sem p50 n)

**Ordered logit results
ologit trustq i.attlean i.race3 Age Ideology edu Income sex worry Safe hood experience if Condition=="Control", robust 
margins i.attlean if(attlean==1 | attlean==2), atmeans vsquish
marginsplot, recast(scatter) scheme(s1mono) horizontal title("Trust in Police (Study 2)", size (medium) margin(medium)) ylab() ytitle("Attribution for Racial Disparities") yscale(range(.5 2.5)) xtitle("Predicted Trust in Police")
*graph export Study2TrustOlogit.pdf, replace
*outreg2 using myreg.doc, replace ctitle(Model 1) label sideway

**Controls for partisanship
tab Party
gen party7=.
replace party7=1 if PartyDem==1
replace party7=2 if PartyDem==2
replace party7=3 if PartyInd==2
replace party7=4 if PartyInd==3
replace party7=5 if PartyInd==1
replace party7=6 if PartyRepub==2
replace party7=7 if PartyRepub==1
tab party7

gen Republican=.
replace Republican=1 if party7==7
replace Republican=1 if party7==6
replace Republican=1 if party7==5
replace Republican=0 if party7==4
replace Republican=0 if party7==3
replace Republican=0 if party7==2
replace Republican=0 if party7==1
tab Republican

gen Independent=.
replace Independent=1 if party7==4
replace Independent=0 if party7==1
replace Independent=0 if party7==2
replace Independent=0 if party7==3
replace Independent=0 if party7==5
replace Independent=0 if party7==6
replace Independent=0 if party7==7
tab Independent

regress trustq i.attlean i.race3 Age Ideology edu Income sex Republican Independent worry Safe hood experience  if Condition=="Control", robust 
*outreg2 using myreg.doc, replace ctitle(Model 1) label sideway

**Full Sample Regression with dummy for experimental condition
regress trustq i.attlean i.race3 Age Ideology edu Income sex group worry Safe hood experience, robust 
*outreg2 using myreg.doc, replace ctitle(Model 1) label sideway


**Treatment effects in graphics
regress trustq i.attlean i.group i.attlean##i.group
margins attlean, dydx(i.group)
marginsplot, recast(scatter) scheme(s1mono) horizontal title("Change in Trust (Treatment Effect) by Attribution (Study 2)", size (medium) margin(medium)) xline(0,lpattern(dash)) ytitle("Attribution for Racial Disparity", margin(small)) yscale(rev range(0.5 4.5)) ylabel( 1 "Blacks commit more violations" 2 "Police racially profile" 3 "Police more likely where blacks live" 4 "Don't Know", labsize(small)) xtitle("Change in Trust (Treatment Effect)", margin(small) )
*graph export Study2TreatmentEffectPlot.pdf, replace


**Predicting Attribution type
mlogit attlean i.race3 Age Ideology edu Income sex  worry Safe hood experience
*outreg2 using myreg.doc, replace label sideway

